## Versioning.

`kooplearn` uses [Hatch](https://hatch.pypa.io) as a build tool. Refer to 

- Refer to the [official documentation](https://hatch.pypa.io/1.9/version/#pyprojecttoml), as well as
- [This tutorial](https://waylonwalker.com/hatch-version/) post

To understand how to automatically bump the version upon for a new release.

## Packaging & Distributing:
